aboutsummaryrefslogtreecommitdiff
path: root/refs/refs-internal.h
diff options
context:
space:
mode:
authorMichael Haggerty <mhagger@alum.mit.edu>2016-06-18 06:15:09 +0200
committerJunio C Hamano <gitster@pobox.com>2016-06-20 11:38:18 -0700
commit4633a846f5cf085bc11de702d0e78177aa44a907 (patch)
tree0c90769de0e316640376ed9ca3046e7209019663 /refs/refs-internal.h
parent067622b0e8afde8b39884e221b7a56299036f6d9 (diff)
downloadgit-4633a846f5cf085bc11de702d0e78177aa44a907.tar.gz
git-4633a846f5cf085bc11de702d0e78177aa44a907.tar.xz
refs: use name "prefix" consistently
In the context of the for_each_ref() functions, call the prefix that references must start with "prefix". (In some places it was called "base".) This is clearer, and also prevents confusion with another planned use of the word "base". Signed-off-by: Michael Haggerty <mhagger@alum.mit.edu> Signed-off-by: Junio C Hamano <gitster@pobox.com>
Diffstat (limited to 'refs/refs-internal.h')
-rw-r--r--refs/refs-internal.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/refs/refs-internal.h b/refs/refs-internal.h
index b4dd5453e..8ad02d84d 100644
--- a/refs/refs-internal.h
+++ b/refs/refs-internal.h
@@ -250,16 +250,16 @@ int rename_ref_available(const char *oldname, const char *newname);
/*
* Call fn for each reference in the specified submodule for which the
* refname begins with base. If trim is non-zero, then trim that many
* characters off the beginning of each refname before passing the
* refname to fn. flags can be DO_FOR_EACH_INCLUDE_BROKEN to include
* broken references in the iteration. If fn ever returns a non-zero
* value, stop the iteration and return that value; otherwise, return
* 0.
*
* This is the common backend for the for_each_*ref* functions.
*/
-int do_for_each_ref(const char *submodule, const char *base,
+int do_for_each_ref(const char *submodule, const char *prefix,
each_ref_fn fn, int trim, int flags, void *cb_data);
/*
@@ -250,16 +250,16 @@ int rename_ref_available(const char *oldname, const char *newname);
/*
* Call fn for each reference in the specified submodule for which the
- * refname begins with base. If trim is non-zero, then trim that many
- * characters off the beginning of each refname before passing the
- * refname to fn. flags can be DO_FOR_EACH_INCLUDE_BROKEN to include
- * broken references in the iteration. If fn ever returns a non-zero
- * value, stop the iteration and return that value; otherwise, return
- * 0.
+ * refname begins with prefix. If trim is non-zero, then trim that
+ * many characters off the beginning of each refname before passing
+ * the refname to fn. flags can be DO_FOR_EACH_INCLUDE_BROKEN to
+ * include broken references in the iteration. If fn ever returns a
+ * non-zero value, stop the iteration and return that value;
+ * otherwise, return 0.
*
* This is the common backend for the for_each_*ref* functions.